<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Narcissism
 */

if ( ! function_exists( 'narcissism_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function narcissism_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'narcissism' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'narcissism' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'narcissism' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'narcissism_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function narcissism_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'narcissism' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'narcissism' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link',     'narcissism' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'narcissism_post_meta' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function narcissism_post_meta() { ?>
    <?php if ( is_sticky() ) : ?>
        <span class="sticky">Sticky</span>
    <?php endif; ?>
    
	<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
	    <br />
        <span class="reply-link"><?php comments_popup_link( __( 'Leave a comment', 'narcissism' ), __( '1 Comment', 'narcissism' ), __( '% Comments', 'narcissism' ) ); ?></span>
    <?php endif; ?>
    <br />
    <?php edit_post_link( __( 'Edit', 'narcissism' ), '<span class="edit-link">', '</span>' ); ?>
    <hr />
    <?php
    $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
        $time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
    }
    
    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() ),
        esc_attr( get_the_modified_date( 'c' ) ),
        esc_html( get_the_modified_date() )
    );
    
    printf( __( '<span class="time-date-info"><span class="posted-on">Posted on %1$s</span><span class="byline"> by %2$s</span>', 'narcissism' ),
        sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
        	esc_url( get_permalink() ),
        	$time_string
        ),
        sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s">%2$s</a></span></span>',
        	esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        	esc_html( get_the_author() )
        )
    );   
}
endif;

if ( ! function_exists( 'narcissism_single_post_meta' ) ) :
/**
 * Prints HTML with meta information for the single post view
 */
function narcissism_single_post_meta() {
    /* translators: used between list items, there is a space after the comma */
    $categories = get_the_category_list( __( ', ', 'narcissism' ) );
    
    /* translators: used between list items, there is a space after the comma */
    $tags = get_the_tag_list( null, __( ', ', 'narcissism' ) ); ?>
    
    <hr />
    <?php edit_post_link( __( 'Edit', 'narcissism' ), '<span class="edit-link">', '</span><br />' ); ?>
    
    <?php if ( $categories ) : ?>
        <span class="cat-links"><?php printf( __( 'Categorized under %s', 'narcissism' ), $categories ); ?></span>
        <br />
    <?php endif; ?>
    
    <?php if ( $tags ) : ?>
        <span class="tag-links"><?php printf( __( 'Tagged as %s', 'narcissism' ), $tags ); ?></span>
        <br />
    <?php endif; ?>
    
    <?php
    if ( is_attachment() && wp_attachment_is_image() ) :
        $attachment_args = wp_get_attachment_metadata();
        $attachment_height = $attachment_args['height'];
        $attachment_width = $attachment_args['width']; ?>
        
        <span class="image-size-links"><a href="<?php echo esc_html( wp_get_attachment_url() ); ?>">
            <?php printf( __( 'See full-size image: (%1$s x %2$s)', 'narcissism' ),
                $attachment_height,
                $attachment_width
            ); ?>
        </a></span>
        <br />
    <?php endif; ?>
        
    <?php
    $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
        $time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
    }
    
    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() ),
        esc_attr( get_the_modified_date( 'c' ) ),
        esc_html( get_the_modified_date() )
    );
    
    printf( __( '<span class="time-date-info"><span class="posted-on">Posted on %1$s</span><span class="byline"> by %2$s</span>', 'narcissism' ),
        sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
        	esc_url( get_permalink() ),
        	$time_string
        ),
        sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s">%2$s</a></span></span>',
        	esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        	esc_html( get_the_author() )
        )
    );
}
endif;
/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function narcissism_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'narcissism_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'narcissism_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so narcissism_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so narcissism_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in narcissism_categorized_blog.
 */
function narcissism_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'narcissism_categories' );
}
add_action( 'edit_category', 'narcissism_category_transient_flusher' );
add_action( 'save_post',     'narcissism_category_transient_flusher' );
